/**
 * Analytics client - programmatic API
 */
import type { AnalyticsClient, PageViewData } from './types';
/**
 * Initialize client with page view data
 * Called by beacon or can be called manually
 */
export declare function initClient(pv: PageViewData): void;
/**
 * Update page view data
 */
export declare function updatePageView(updates: Partial<PageViewData>): void;
/**
 * Get current page view data
 */
export declare function getPageView(): PageViewData | null;
/**
 * Reset session (keep page-level metrics, reset session metrics)
 */
export declare function resetSession(): void;
/**
 * Send analytics data
 */
export declare function send(force?: boolean): void;
/**
 * Track a custom event
 */
export declare function track(name: string, properties?: Record<string, unknown>): void;
/**
 * Identify a user
 */
export declare function identify(id: string, traits?: Record<string, unknown>): void;
/**
 * Flush pending events
 */
export declare function flush(): void;
/**
 * Get the analytics client
 */
export declare function getClient(): AnalyticsClient;
/**
 * Set up client as window.global
 */
export declare function setupGlobal(): void;
//# sourceMappingURL=client.d.ts.map