/**
 * Analytics configuration resolution
 */
import type { AnalyticsConfig } from './types';
/** Window with Agentuity analytics globals */
declare global {
    interface Window {
        __AGENTUITY_ANALYTICS__?: AnalyticsConfig;
        agentuityAnalytics?: import('./types').AnalyticsClient;
    }
}
/** Default collect endpoint */
export declare const DEFAULT_ENDPOINT = "/_agentuity/webanalytics/collect";
/**
 * Get analytics config from window global
 */
export declare function getConfig(): AnalyticsConfig | null;
/**
 * Check if analytics is enabled
 */
export declare function isEnabled(): boolean;
/**
 * Check if running in dev mode
 */
export declare function isDevmode(): boolean;
/**
 * Get the collect endpoint
 */
export declare function getEndpoint(): string;
//# sourceMappingURL=config.d.ts.map