/**
 * Analytics utility functions
 */
import type { GeoLocation } from './types';
/**
 * Generate a unique ID
 */
export declare function generateId(): string;
/**
 * Safely stringify an object, handling circular references
 */
export declare function safeStringify(obj: unknown): string;
/**
 * Strip query string from URL to prevent sensitive data leakage
 */
export declare function stripQueryString(url: string): string;
/**
 * Get UTM parameters from URL
 */
export declare function getUTMParams(): Record<string, string>;
/**
 * Get or create visitor ID from localStorage
 */
export declare function getVisitorId(): string;
/**
 * Fetch geo location from service
 */
export declare function fetchGeo(): Promise<GeoLocation | null>;
//# sourceMappingURL=util.d.ts.map