/**
 * Analytics beacon - auto-initializing script
 *
 * Import this module to automatically start tracking:
 * ```typescript
 * import '@agentuity/analytics/beacon';
 * ```
 *
 * Requires window.__AGENTUITY_ANALYTICS__ to be set by server.
 */
export {};
//# sourceMappingURL=beacon.d.ts.map