/**
 * Analytics configuration resolution
 */
/** Default collect endpoint */
export const DEFAULT_ENDPOINT = '/_agentuity/webanalytics/collect';
/**
 * Get analytics config from window global
 */
export function getConfig() {
    return window.__AGENTUITY_ANALYTICS__ ?? null;
}
/**
 * Check if analytics is enabled
 */
export function isEnabled() {
    const config = getConfig();
    return config?.enabled === true;
}
/**
 * Check if running in dev mode
 */
export function isDevmode() {
    return getConfig()?.isDevmode ?? false;
}
/**
 * Get the collect endpoint
 */
export function getEndpoint() {
    return getConfig()?.endpoint ?? DEFAULT_ENDPOINT;
}
//# sourceMappingURL=config.js.map